@@ -1,6 +1,6 @@
 package Log::Dispatch;
-BEGIN {
-  $Log::Dispatch::VERSION = '2.28';
+{
+  $Log::Dispatch::VERSION = '2.30';
 }
 
 use 5.006;
@@ -9,18 +9,40 @@ use strict;
 use warnings;
 
 use base qw( Log::Dispatch::Base );
-use Params::Validate qw(validate_with ARRAYREF CODEREF);
+use Class::Load qw( load_class );
+use Params::Validate 0.15 qw(validate_with ARRAYREF CODEREF);
 use Carp ();
 
 our %LEVELS;
 
 BEGIN {
-    foreach my $l (
-        qw( debug info notice warn warning err error crit critical alert emerg emergency )
-        ) {
+    my %level_map = (
+        (
+            map { $_ => $_ }
+                qw(
+                debug
+                info
+                notice
+                warning
+                error
+                critical
+                alert
+                emergency
+                )
+        ),
+        warn  => 'warning',
+        err   => 'error',
+        crit  => 'critical',
+        emerg => 'emergency',
+    );
+
+    foreach my $l ( keys %level_map ) {
         my $sub = sub {
             my $self = shift;
-            $self->log( level => $l, message => "@_" );
+            $self->log(
+                level   => $level_map{$l},
+                message => @_ > 1 ? "@_" : $_[0],
+            );
         };
 
         $LEVELS{$l} = 1;
@@ -87,7 +109,7 @@ sub _add_output {
         ? substr( $class, 1 )
         : "Log::Dispatch::$class";
 
-    _require_dynamic($full_class);
+    load_class($full_class);
 
     $self->add( $full_class->new(@_) );
 }
@@ -225,13 +247,18 @@ sub would_log {
     return 0;
 }
 
-sub _require_dynamic {
-    my ($class) = @_;
-
-    local $@;
-    eval "require $class";
-    die $@ if $@;
-}
+sub is_debug     { $_[0]->would_log('debug') }
+sub is_info      { $_[0]->would_log('info') }
+sub is_notice    { $_[0]->would_log('notice') }
+sub is_warning   { $_[0]->would_log('warning') }
+sub is_warn      { $_[0]->would_log('warn') }
+sub is_error     { $_[0]->would_log('error') }
+sub is_err       { $_[0]->would_log('err') }
+sub is_critical  { $_[0]->would_log('critical') }
+sub is_crit      { $_[0]->would_log('crit') }
+sub is_alert     { $_[0]->would_log('alert') }
+sub is_emerg     { $_[0]->would_log('emerg') }
+sub is_emergency { $_[0]->would_log('emergency') }
 
 1;
 
@@ -247,7 +274,7 @@ Log::Dispatch - Dispatches messages to one or more outputs
 
 =head1 VERSION
 
-version 2.28
+version 2.30
 
 =head1 SYNOPSIS
 
@@ -319,7 +346,7 @@ string following '+' is taken to be a full classname. e.g.
                  [ '+My::Dispatch', min_level => 'info' ] ]
 
 For each inner list, a new output object is created and added to the
-dispatcher (via L</add>).
+dispatcher (via the C<add() method>).
 
 See L<OUTPUT CLASSES> for the parameters that can be used when creating an
 output object.
@@ -383,6 +410,9 @@ If you pass an array to these methods, it will be stringified as is:
 
  $log->alert("@array");
 
+You can also pass a subroutine reference, just like passing one to the
+C<log()> method.
+
 =item * log_and_die( level => $, message => $ or \& )
 
 Has the same behavior as calling C<log()> but calls
@@ -432,6 +462,12 @@ valid log level.  Can be called as either a class or object method.
 Given a log level, returns true or false to indicate whether or not
 anything would be logged for that log level.
 
+=item * is_C<$level>
+
+There are methods for every log level: C<is_debug()>, C<is_warning()>, etc.
+
+This returns true if the logger will log a message at the given level.
+
 =back
 
 =head2 Output objects
@@ -480,11 +516,11 @@ form of generated names, as they may change.
 
 =item * min_level ($)
 
-The minimum L<logging level|Log Levels> this object will accept. Required.
+The minimum L<logging level|LOG LEVELS> this object will accept. Required.
 
 =item * max_level ($)
 
-The maximum L<logging level|Log Levels> this object will accept.  By default
+The maximum L<logging level|LOG LEVELS> this object will accept.  By default
 the maximum is the highest possible level (which means functionally that the
 object has no maximum).
 
@@ -507,7 +543,7 @@ message!
 
 If true, a callback will be added to the end of the callbacks list that adds
 a newline to the end of each message. Default is false, but some
-output classes may decide to make the default true. See L</NEWLINES> for more details.
+output classes may decide to make the default true.
 
 =back
 
@@ -612,7 +648,26 @@ or via email at bug-log-dispatch@rt.cpan.org.
 
 Support questions can be sent to me at my email address, shown below.
 
-The code repository is at http://hg.urth.org/hg/Log-Dispatch.
+=head1 DONATIONS
+
+If you'd like to thank me for the work I've done on this module,
+please consider making a "donation" to me via PayPal. I spend a lot of
+free time creating free software, and would appreciate any support
+you'd care to offer.
+
+Please note that B<I am not suggesting that you must do this> in order
+for me to continue working on this particular software. I will
+continue to do so, inasmuch as I have in the past, for as long as it
+interests me.
+
+Similarly, a donation made in this way will probably not make me work
+on this software much more, unless I get so many donations that I can
+consider working on free software full time, which seems unlikely at
+best.
+
+To donate, log into PayPal and send money to autarch@urth.org or use
+the button on this page:
+L<http://www.urth.org/~autarch/fs-donation.html>
 
 =head1 SEE ALSO
 
@@ -629,11 +684,11 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2010 by Dave Rolsky.
+This software is Copyright (c) 2011 by Dave Rolsky.
 
 This is free software, licensed under:
 
-  The Artistic License 2.0
+  The Artistic License 2.0 (GPL Compatible)
 
 =cut
 
